@@ -37,15 +37,15 @@ public:
 
     QString       actionId;
     PolKitAction *pkAction;
-    PolKitResult  pkResult;
-    uint          targetPID;
+    Auth::Result  pkResult;
+    qint64        targetPID;
 
     void                 updateAction();
     bool                 computePkResult();
     void                 configChanged();
     static polkit_bool_t auth_foreach_revoke(PolKitAuthorizationDB *authdb,
-                                                 PolKitAuthorization   *auth,
-                                                 void                  *user_data);
+            PolKitAuthorization   *auth,
+            void                  *user_data);
 
     bool    initiallyChecked;
 
@@ -133,20 +133,20 @@ Action::~Action()
 bool Action::activate(WId winId)
 {
     switch (d->pkResult) {
-    case POLKIT_RESULT_YES:
+    case Auth::Yes:
         // If PolicyKit says yes.. emit the 'activated' signal
         emit activated();
         return true;
         break;
 
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_ONE_SHOT:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_SESSION:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_ALWAYS:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_ONE_SHOT:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_SESSION:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_ALWAYS:
+    case Auth::AdminAuthOneShot:
+    case Auth::AdminAuth:
+    case Auth::AdminAuthKeepAlways:
+    case Auth::AdminAuthKeepSession:
+    case Auth::SelfAuthOneShot:
+    case Auth::SelfAuth:
+    case Auth::SelfAuthKeepAlways:
+    case Auth::SelfAuthKeepSession:
         /* Otherwise, if the action needs auth..  stop the emission
          * and start auth process..
          */
@@ -167,7 +167,7 @@ bool Action::activate(WId winId)
         break;
 
     default:
-    case POLKIT_RESULT_NO:
+    case Auth::No:
         if (d->noEnabled) {
             /* If PolicyKit says no... and we got here.. it means
              * that the user set the property "no-enabled" to
@@ -202,8 +202,8 @@ void Action::Private::updateAction()
 
     switch (pkResult) {
     default:
-    case POLKIT_RESULT_UNKNOWN:
-    case POLKIT_RESULT_NO:
+    case Auth::Unknown:
+    case Auth::No:
         /* TODO: see if we're self-blocked */
         if (pkAction != NULL &&
                 polkit_authorization_db_is_uid_blocked_by_self(authdb,
@@ -241,14 +241,14 @@ void Action::Private::updateAction()
         }
         break;
 
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_ONE_SHOT:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_SESSION:
-    case POLKIT_RESULT_ONLY_VIA_ADMIN_AUTH_KEEP_ALWAYS:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_ONE_SHOT:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_SESSION:
-    case POLKIT_RESULT_ONLY_VIA_SELF_AUTH_KEEP_ALWAYS:
+    case Auth::AdminAuthOneShot:
+    case Auth::AdminAuth:
+    case Auth::AdminAuthKeepAlways:
+    case Auth::AdminAuthKeepSession:
+    case Auth::SelfAuthOneShot:
+    case Auth::SelfAuth:
+    case Auth::SelfAuthKeepAlways:
+    case Auth::SelfAuthKeepSession:
         parent->setVisible(authVisible && masterVisible);
         parent->setEnabled(authEnabled && masterEnabled);
         qobject_cast<QAction*>(parent)->setText(authText);
@@ -264,7 +264,7 @@ void Action::Private::updateAction()
         }
         break;
 
-    case POLKIT_RESULT_YES:
+    case Auth::Yes:
         parent->setVisible(yesVisible && masterVisible);
         parent->setEnabled(yesEnabled && masterEnabled);
         qobject_cast<QAction*>(parent)->setText(yesText);
@@ -294,13 +294,13 @@ void Action::Private::configChanged()
 
 bool Action::Private::computePkResult()
 {
-    PolKitResult old_result;
+    Auth::Result old_result;
 
     old_result = pkResult;
-    pkResult = POLKIT_RESULT_UNKNOWN;
+    pkResult = Auth::Unknown;
 
     if (pkAction == NULL) {
-        pkResult = POLKIT_RESULT_YES;
+        pkResult = Auth::Yes;
     } else {
         // set revokeIfOneShot to false as we only want to check it,
         // otherwise we would be revoking one shot actions
@@ -310,7 +310,7 @@ bool Action::Private::computePkResult()
     return old_result != pkResult;
 }
 
-pid_t Action::targetPID() const
+qint64 Action::targetPID() const
 {
     if (d->targetPID != 0)
         return d->targetPID;
@@ -318,7 +318,7 @@ pid_t Action::targetPID() const
         return QCoreApplication::applicationPid();
 }
 
-void Action::setTargetPID(pid_t pid)
+void Action::setTargetPID(qint64 pid)
 {
     d->targetPID = pid;
 
@@ -330,19 +330,19 @@ void Action::setPolkitAction(const QString &actionId)
 {
     PolKitAction *pkAction = polkit_action_new();
     if (actionId.isEmpty() ||
-        !polkit_action_set_action_id(pkAction, actionId.toAscii().data())) {
+            !polkit_action_set_action_id(pkAction, actionId.toAscii().data())) {
         if (d->pkAction != NULL) {
             polkit_action_unref(d->pkAction);
             d->pkAction = NULL;
             d->computePkResult();
             d->updateAction();
         }
-    // Don't bother updating d->actionId if it's the same
-    // value.. it will just cause a lot of unnecessary work as
-    // we'll recompute the answer via PolicyKit..
-    //
-    // unless it's on the initial call (where d->pkAction
-    // is alread NULL) because we need that initial update;
+        // Don't bother updating d->actionId if it's the same
+        // value.. it will just cause a lot of unnecessary work as
+        // we'll recompute the answer via PolicyKit..
+        //
+        // unless it's on the initial call (where d->pkAction
+        // is alread NULL) because we need that initial update;
     } else if (!d->pkAction || d->actionId != actionId) {
         if (d->pkAction != NULL) {
             polkit_action_unref(d->pkAction);
@@ -361,7 +361,7 @@ void Action::setPolkitAction(const QString &actionId)
 
 bool Action::isAllowed() const
 {
-    return d->pkResult == POLKIT_RESULT_YES;
+    return d->pkResult == Auth::Yes;
 }
 
 bool Action::is(const QString &other) const
@@ -374,7 +374,7 @@ void Action::revoke()
     PolKitError *pk_error;
     PolKitAuthorizationDB *authdb;
 
-    if (d->pkResult == POLKIT_RESULT_YES) {
+    if (d->pkResult == Auth::Yes) {
         /* If we already got the authorization.. revoke it! */
         authdb = polkit_context_get_authorization_db(Context::instance()->getPolKitContext());
         if (d->pkAction != NULL && authdb != NULL) {
@@ -383,31 +383,31 @@ void Action::revoke()
             pk_error = NULL;
             num_auths_revoked = 0;
             polkit_authorization_db_foreach_for_action_for_uid(authdb,
-                                                               d->pkAction,
-                                                               getuid(),
-                                                               Private::auth_foreach_revoke,
-                                                               &num_auths_revoked,
-                                                               &pk_error);
+                    d->pkAction,
+                    getuid(),
+                    Private::auth_foreach_revoke,
+                    &num_auths_revoked,
+                    &pk_error);
             if (pk_error != NULL) {
                 qWarning() << "Error removing authorizations: code="
-                           << polkit_error_get_error_code(pk_error) << ": "
-                           << polkit_error_get_error_message(pk_error);
-                polkit_error_free (pk_error);
+                << polkit_error_get_error_code(pk_error) << ": "
+                << polkit_error_get_error_message(pk_error);
+                polkit_error_free(pk_error);
             }
 
             if (pk_error == NULL && num_auths_revoked == 0) {
                 // no authorizations, yet we are authorized.. "grant" a
                 // negative authorization...
-                if (!polkit_authorization_db_grant_negative_to_uid (
+                if (!polkit_authorization_db_grant_negative_to_uid(
                             authdb,
                             d->pkAction,
                             getuid(),
                             NULL, /* no constraints */
                             &pk_error)) {
                     qWarning() << "Error granting negative auth: code="
-                               << polkit_error_get_error_name(pk_error) << ": "
-                               << polkit_error_get_error_message(pk_error);
-                    polkit_error_free (pk_error);
+                    << polkit_error_get_error_name(pk_error) << ": "
+                    << polkit_error_get_error_message(pk_error);
+                    polkit_error_free(pk_error);
                 }
             }
 
@@ -416,8 +416,8 @@ void Action::revoke()
 }
 
 polkit_bool_t Action::Private::auth_foreach_revoke(PolKitAuthorizationDB *authdb,
-                                          PolKitAuthorization   *auth,
-                                          void                  *user_data)
+        PolKitAuthorization   *auth,
+        void                  *user_data)
 {
     PolKitError *pk_error;
     int *num_auths_revoked = (int *) user_data;
@@ -425,9 +425,9 @@ polkit_bool_t Action::Private::auth_foreach_revoke(PolKitAuthorizationDB *authdb
     pk_error = NULL;
     if (!polkit_authorization_db_revoke_entry(authdb, auth, &pk_error)) {
         qWarning() << "Error revoking authorizations: "
-                    << polkit_error_get_error_name(pk_error) << ": "
-                    << polkit_error_get_error_message(pk_error);
-        polkit_error_free (pk_error);
+        << polkit_error_get_error_name(pk_error) << ": "
+        << polkit_error_get_error_message(pk_error);
+        polkit_error_free(pk_error);
     }
 
     if (num_auths_revoked != NULL) {
@@ -771,4 +771,4 @@ bool Action::masterEnabled() const
     return d->masterEnabled;
 }
 
-#include "moc_action.cpp"
\ No newline at end of file
+#include "moc_action.cpp"
