@@ -26,8 +26,9 @@
 
 #include <QtGui/QAction>
 #include <QtCore/QString>
+#include <QProcess>
 
-#include <polkit/polkit.h>
+typedef struct _PolKitAction PolKitAction;
 
 namespace PolkitQt
 {
@@ -61,7 +62,7 @@ public:
      * \param actionId the PolicyKit action Id (e.g.: org.freedesktop.policykit.read)
      * \param parent the object parent
      */
-    Action(const QString &actionId = QString(), QObject *parent = 0);
+    explicit Action(const QString &actionId = QString(), QObject *parent = 0);
     ~Action();
 
 Q_SIGNALS:
@@ -552,12 +553,12 @@ public:
      *
      * \param pid The target process id; 0 if it is the current process
      */
-    void setTargetPID(pid_t pid);
+    void setTargetPID(qint64 pid);
 
     /**
      * \see setTargetPID
      */
-    pid_t targetPID() const;
+    qint64 targetPID() const;
 
     /**
      * This method can be used to check the if the current action
